@@ -9,6 +9,7 @@ use DateTime::Format::Duration;
 
 use Moose;
 extends 'HPC::Runner';
+with 'MooseX::Getopt::Usage';
 
 =head1 NAME
 
@@ -20,11 +21,11 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.33';
+our $VERSION = '2.34';
 
 =head1 SYNOPSIS
 
-Use MCE and MCE::Queue to run arbitrary bash commands in parallel using processes. 
+Use MCE and MCE::Queue to run arbitrary bash commands in parallel using processes.
 
 =cut
 
@@ -112,13 +113,13 @@ sub go{
 
 =head2 parse_file_mce
 
-The default method of parsing the file. 
+The default method of parsing the file.
 
     #starts a comment
     wait - says wait until all other processes/threads exitcode
 
     #this is a one line command
-    echo "starting" 
+    echo "starting"
 
     #This is a multiline command
     echo "starting line 1" \
@@ -132,7 +133,7 @@ sub parse_file_mce{
 
     $DB::single=2;
 
-    my $fh = IO::File->new( $self->infile, q{<} ) or $self->log->fatal("Error opening file  ".$self->infile."  ".$!); 
+    my $fh = IO::File->new( $self->infile, q{<} ) or $self->log->fatal("Error opening file  ".$self->infile."  ".$!);
     die unless $fh;
 
     my $cmd;
@@ -156,7 +157,7 @@ sub parse_file_mce{
                 #Threads
 #                $self->run_command_threads;
                 $self->clear_cmd;
-                $self->inc_counter; 
+                $self->inc_counter;
             }
         }
         else{
@@ -176,7 +177,7 @@ sub parse_file_mce{
 #                #THREADS
 #                $self->threads->wait_all_children;
                 $self->log->info("All children have completed processing!");
-                $self->inc_counter; 
+                $self->inc_counter;
 
             }
             else{
@@ -187,7 +188,7 @@ sub parse_file_mce{
 #                #Threads
 #                $self->run_command_threads;
                 $self->clear_cmd;
-                $self->inc_counter; 
+                $self->inc_counter;
             }
         }
     }
@@ -197,7 +198,7 @@ sub parse_file_mce{
 }
 
 #use namespace::autoclean;
-1; 
+1;
 
 =head1 AUTHOR
 
@@ -224,30 +225,32 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Runner-Init>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HPC-Runner-MCE>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/Runner-Init>
+L<http://annocpan.org/dist/HPC-Runner-MCE>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/Runner-Init>
+L<http://cpanratings.perl.org/d/HPC-Runner-MCE>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Runner-Init/>
+L<http://search.cpan.org/dist/HPC-Runner-MCE/>
 
 =back
 
+=head1 Acknowledgements
 
-=head1 ACKNOWLEDGEMENTS
-
-This module was originally developed at and for Weill Cornell Medical College in Qatar. With approval from WCMC-Q, this information was generalized and put on github, for which the authors would like to express their gratitude.
+This module was originally developed at and for Weill Cornell Medical
+College in Qatar within ITS Advanced Computing Team. With approval from
+WCMC-Q, this information was generalized and put on github, for which
+the authors would like to express their gratitude.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Jillian Rowe.
+Copyright 2014 Weill Cornell Medical College.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
